/**
* Copyright (c) 2008 Moritz Bechler
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
* THE SOFTWARE.
**/

#ifndef PHP_KRB5_KADM_H
#define PHP_KRB5_KADM_H


#include <kadm5/admin.h>

/* KADM5 Object */
	zend_class_entry *krb5_ce_kadm5;

	typedef struct _krb5_kadm5_object {
		zend_object std;
		void *handle;
		krb5_context ctx;
		int refcount;
	} krb5_kadm5_object;

	void php_krb5_free_kadm5_object(krb5_kadm5_object *obj);

	/* Kerberos Admin functions */
	PHP_METHOD(KADM5, __construct);
	PHP_METHOD(KADM5, getPrincipal);
	PHP_METHOD(KADM5, getPrincipals);
	PHP_METHOD(KADM5, createPrincipal);
	PHP_METHOD(KADM5, getPolicy);
	PHP_METHOD(KADM5, createPolicy);
	PHP_METHOD(KADM5, getPolicies);

	static function_entry krb5_kadm5_functions[] = {
		PHP_ME(KADM5, __construct, NULL, ZEND_ACC_CTOR | ZEND_ACC_PUBLIC)
		PHP_ME(KADM5, getPrincipal, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5, getPrincipals, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5, createPrincipal, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5, getPolicy, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5, createPolicy, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5, getPolicies, NULL, ZEND_ACC_PUBLIC)
		{NULL, NULL, NULL}		
	};

/* KADM5Principal Object */
	zend_class_entry *krb5_ce_kadm5_principal;

	typedef struct _krb5_kadm5_principal_object {
		zend_object std;
		int loaded;
		long int update_mask;
		kadm5_principal_ent_rec data;
		krb5_kadm5_object *conn;
	} krb5_kadm5_principal_object;

	static void php_krb5_kadm5_principal_object_dtor(void *obj, zend_object_handle handle TSRMLS_DC);
	zend_object_value php_krb5_kadm5_principal_object_new(zend_class_entry *ce TSRMLS_DC);

	PHP_METHOD(KADM5Principal, __construct);
	PHP_METHOD(KADM5Principal, load);
	PHP_METHOD(KADM5Principal, save);
	PHP_METHOD(KADM5Principal, delete);
	PHP_METHOD(KADM5Principal, rename);

	PHP_METHOD(KADM5Principal, changePassword);

	PHP_METHOD(KADM5Principal, getPropertyArray);

	PHP_METHOD(KADM5Principal, getName);
	PHP_METHOD(KADM5Principal, getExpiryTime);
	PHP_METHOD(KADM5Principal, setExpiryTime);
	PHP_METHOD(KADM5Principal, getLastPasswordChange);
	PHP_METHOD(KADM5Principal, getPasswordExpiryTime);
	PHP_METHOD(KADM5Principal, setPasswordExpiryTime);
	PHP_METHOD(KADM5Principal, getMaxTicketLifetime);
	PHP_METHOD(KADM5Principal, setMaxTicketLifetime);
	PHP_METHOD(KADM5Principal, getLastModifier);
	PHP_METHOD(KADM5Principal, getLastModificationDate);
	PHP_METHOD(KADM5Principal, getKeyVNO);
	PHP_METHOD(KADM5Principal, setKeyVNO);
	PHP_METHOD(KADM5Principal, getMasterKeyVNO);
	PHP_METHOD(KADM5Principal, getAttributes);
	PHP_METHOD(KADM5Principal, getAuxAttributes);
	PHP_METHOD(KADM5Principal, getPolicy);
	PHP_METHOD(KADM5Principal, setPolicy);
	PHP_METHOD(KADM5Principal, clearPolicy);
	PHP_METHOD(KADM5Principal, getLastSuccess);
	PHP_METHOD(KADM5Principal, getLastFailed);
	PHP_METHOD(KADM5Principal, getFailedAuthCount);
	PHP_METHOD(KADM5Principal, resetFailedAuthCount);

	static function_entry krb5_kadm5_principal_functions[] = {
		PHP_ME(KADM5Principal, __construct, NULL, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
		PHP_ME(KADM5Principal, load, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, save, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, delete, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, rename, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, changePassword, NULL, ZEND_ACC_PUBLIC)

		PHP_ME(KADM5Principal, getPropertyArray, NULL, ZEND_ACC_PUBLIC)

		PHP_ME(KADM5Principal, getName, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getExpiryTime, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, setExpiryTime, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getLastPasswordChange, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getPasswordExpiryTime, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, setPasswordExpiryTime, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getMaxTicketLifetime, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, setMaxTicketLifetime, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getLastModifier, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getLastModificationDate, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getKeyVNO, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, setKeyVNO, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getMasterKeyVNO, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getAttributes, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getAuxAttributes, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getPolicy, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, setPolicy, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, clearPolicy, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getLastSuccess, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getLastFailed, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, getFailedAuthCount, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Principal, resetFailedAuthCount, NULL, ZEND_ACC_PUBLIC)
		{ NULL, NULL, NULL }
	};

/* KADM5Policy Object */
	zend_class_entry *krb5_ce_kadm5_policy;

	typedef struct _krb5_kadm5_policy_object {
		zend_object std;
		char *policy;
		long int update_mask;
		kadm5_policy_ent_rec data;
		krb5_kadm5_object *conn;
	} krb5_kadm5_policy_object;

	static void php_krb5_kadm5_policy_object_dtor(void *obj, zend_object_handle handle TSRMLS_DC);
	zend_object_value php_krb5_kadm5_policy_object_new(zend_class_entry *ce TSRMLS_DC);

	PHP_METHOD(KADM5Policy, __construct);
	PHP_METHOD(KADM5Policy, __destruct);
	PHP_METHOD(KADM5Policy, load);
	PHP_METHOD(KADM5Policy, save);
	PHP_METHOD(KADM5Policy, delete);

	PHP_METHOD(KADM5Policy, getPropertyArray);

	PHP_METHOD(KADM5Policy, getName);
	PHP_METHOD(KADM5Policy, getMinPasswordLife);
	PHP_METHOD(KADM5Policy, setMinPasswordLife);
	PHP_METHOD(KADM5Policy, getMaxPasswordLife);
	PHP_METHOD(KADM5Policy, setMaxPasswordLife);
	PHP_METHOD(KADM5Policy, getMinPasswordLength);
	PHP_METHOD(KADM5Policy, setMinPasswordLength);
	PHP_METHOD(KADM5Policy, getMinPasswordClasses);
	PHP_METHOD(KADM5Policy, setMinPasswordClasses);
	PHP_METHOD(KADM5Policy, getHistoryNum);
	PHP_METHOD(KADM5Policy, setHistoryNum);
	PHP_METHOD(KADM5Policy, getReferenceCount);


	static function_entry krb5_kadm5_policy_functions[] = {
		PHP_ME(KADM5Policy, __construct, NULL, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
		PHP_ME(KADM5Policy, load, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, save, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, delete, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, getPropertyArray, NULL, ZEND_ACC_PUBLIC)

		PHP_ME(KADM5Policy, getName, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, getMinPasswordLife, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, setMinPasswordLife, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, getMaxPasswordLife, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, setMaxPasswordLife, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, getMinPasswordLength, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, setMinPasswordLength, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, getMinPasswordClasses, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, setMinPasswordClasses, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, getHistoryNum, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, setHistoryNum, NULL, ZEND_ACC_PUBLIC)
		PHP_ME(KADM5Policy, getReferenceCount, NULL, ZEND_ACC_PUBLIC)
		{ NULL, NULL, NULL }
	};

#endif
